#
# spec file for package qore-json-module
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define module_api %(qore --latest-module-api 2>/dev/null)
Name:           qore-json-module
Version:        1.7
Release:        bp153.1.1
Summary:        JSON module for Qore
License:        LGPL-2.0-or-later OR GPL-2.0-or-later OR MIT
URL:            https://qore.org
Source:         https://github.com/qorelanguage/module-json/releases/download/v%{version}/qore-json-module-%{version}.tar.bz2
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  openssl-devel
BuildRequires:  qore
BuildRequires:  qore-devel >= 0.8.5
Requires:       %{_bindir}/env
Requires:       qore-module-api-%{module_api}

%description
This package contains the json module for the Qore Programming Language.

JSON is a concise human-readable data serialization format.

%prep
%setup -q

%build
# Remove -m32 and -m64 options except for x86* and ppc*
%ifnarch %{ix86} x86_64 ppc64 ppc64le
sed -i 's/-m32//g;s/-m64//g' configure
%endif
# FIXME: you should use the %%configure macro
CFLAGS="%{optflags}" CXXFLAGS="%{optflags}" ./configure RPM_OPT_FLAGS="%{optflags}" --prefix=%{_prefix} --disable-debug
%make_build

%install
mkdir -p %{buildroot}%{_datadir}/doc/qore-json-module
%make_install

%files
%{_datadir}/qore-modules
%{_libdir}/qore-modules
%license COPYING.LGPL COPYING.MIT
%doc README RELEASE-NOTES

%package doc
Summary:        JSON module for Qore

%description doc
This package contains the HTML documentation and example programs for the Qore
json module.

%files doc
%doc docs/json/html docs/JsonRpcHandler/html examples/ test/

%changelog
* Sun Aug 16 2020 Dirk Mueller <dmueller@suse.com>
- update to 1.7:
  * deprecated support for the non-published JSON-RPC 1.1 protocol
  * added support for JSON-RPC 2.0
  * added the JsonRpcConnection user module
  * improved argument error messages with RPC calls in the JsonRpcHandler module (issue 2573)
  * fixed date serialization to use ISO-8601 format (instead of near-ISO-8601 format: issue 2655)
  * parse_json() now ignores UTF-8 and Unicode BOMs at the start of passed JSON string (issue 1398)
  * fixed a bug in request logging in the JsonRpcHandler module (issue 1487)
  * fixed a bug serializing hash keys with embedded quotes (issue 2242)
  * serialize binary values as base64-encoded strings
  * user modules moved to top-level qore module directory from version-specific module directory since they are valid for multiple versions of qore
  * serialize nan, +/-inf as null according to the JSON spec
  * added detection for invalid JSON-RPC calls and added a more user-friendly error message in the JsonRpcHandler module
  * new functions added conforming to Qore's function naming convention, old camel-case functions deprecated
  * JSON tests ported to QUnit
  * Qore 0.8.12 required as a minimum to build
  * JSON output is more compact; less extraneous whitespace is used
- remove 0001-set-64bit-for-other-architectures.patch: upstream
* Mon Apr 30 2018 guillaume.gardet@opensuse.org
- Remove -m32 and -m64 options except for x86* and ppc*
* Mon Dec 22 2014 dimstar@opensuse.org
- Don't start fdupes over docs: it can cause build failures if the
  link is not in the direction expected.
* Mon Aug  4 2014 dvaleev@suse.com
- Set 64bit for powerpc64, aarch64 and s390x
- added patches:
  * 0001-set-64bit-for-other-architectures.patch
* Wed Jul 30 2014 petr@yarpen.cz
- migrated to OBS file layout
